@@ -14,19 +14,23 @@ push!(args, "-isystem$(mpi_include_dir)")
 
 # Compiler flags from Yggdrasil (??)
 # https://github.com/JuliaPackaging/Yggdrasil/blob/9d131ba0e4aa393b00f4d71ef5a3f909419a70a7/H/HYPRE/build_tarballs.jl
-push!(args, "-DHYPRE_ENABLE_SHARED=ON")
+push!(args, "-DBUILD_SHARED_LIBS=ON")
 push!(args, "-DHYPRE_ENABLE_HYPRE_BLAS=ON")
 push!(args, "-DHYPRE_ENABLE_HYPRE_LAPACK=ON")
 push!(args, "-DHYPRE_ENABLE_CUDA_STREAMS=OFF")
 push!(args, "-DHYPRE_ENABLE_CUSPARSE=OFF")
 push!(args, "-DHYPRE_ENABLE_CURAND=OFF")
+push!(args, "-DHYPRE_ENABLE_OPENMP=ON")
 
-headers = joinpath.(hypre_include_dir, [
-    "HYPRE.h",
-    "HYPRE_IJ_mv.h",
-    "HYPRE_parcsr_mv.h",
-    "HYPRE_parcsr_ls.h",
-])
+headers = joinpath.(
+    hypre_include_dir,
+    [
+        "HYPRE.h",
+        "HYPRE_IJ_mv.h",
+        "HYPRE_parcsr_mv.h",
+        "HYPRE_parcsr_ls.h",
+    ]
+)
 
 ctx = create_context(headers, args, options)
 
